# A partial automation preset for visual media that will fill the screen
FILL = { 'x': 960, 'y': 540, 'w': 1920, 'h': 1080, 'r': 0 }


def get_scale(w, h, fit_w, fit_h, mode):
  '''
  Returns the scale needed to fit the specified 'w' and 'h' into the bounds defined by 'fit_w' and 'fit_h', abiding by
  the mode of either 'contain' or 'cover'. The modes have the same meaning as for the object-fit property in CSS, see
  here: https://www.w3schools.com/css/css3_object-fit.asp
  '''
  if mode == 'contain':
    return min(fit_w / w, fit_h / h)
  if mode == 'cover':
    return max(fit_w / w, fit_h / h)
  raise Exception('Unrecognized scale mode: %s' % mode)


def get_scaled_bounds(resource, fit_w=1920, fit_h=1080):
  '''
  Returns a dictionary containing 'w' and 'h', determined by applying the metadata's 'scale' mode to its 'w' and 'h'
  properties.
  '''
  metadata = resource['metadata']
  scale = get_scale(metadata['w'], metadata['h'], fit_w, fit_h, metadata.get('scale') or 'contain')
  w = scale * metadata['w']
  h = scale * metadata['h']
  return { 'w': w, 'h': h }


def get_rotated_bounds(width, height, r):
  '''
  Returns a tuple of (width, height) that defines the size of the bounding box for an input with the specified bounds
  and rotation 'r' in degrees
  '''
  if r % 180 == 0:
    return width, height
  if r % 90 == 0:
    return height, width
  # TODO: might be nice to have this...
  raise NotImplementedError('Not implemented for arbitrary rotations')
